import 'package:flutter/widgets.dart';
import 'package:keyboard_focus_manager/src/widgets/close_keyboard_button.dart';
import 'package:keyboard_visibility/keyboard_visibility.dart';

class CloseKeyboardOverlay {
  final _keyboardVisibilityNotification = KeyboardVisibilityNotification();

  OverlayEntry overlayEntry;
  int _subscribingId;

  void listenKeyboardVisibility(
    BuildContext context, {
    String closeButtonLabel,
    TextStyle closeButtonLabelStyle,
  }) {
    _subscribingId = _keyboardVisibilityNotification.addNewListener(
      onChange: (bool visible) {
        visible
            ? insertDoneButtonOverlay(
                context,
                closeButtonLabel: closeButtonLabel,
                closeButtonLabelStyle: closeButtonLabelStyle,
              )
            : removeOverlay();
      },
    );
  }

  void removeKeyboardVisibilityListener() {
    if (_subscribingId != null) {
      _keyboardVisibilityNotification.removeListener(_subscribingId);
    }
  }

  void insertDoneButtonOverlay(
    BuildContext context, {
    String closeButtonLabel,
    TextStyle closeButtonLabelStyle,
  }) {
    if (overlayEntry == null) {
      OverlayState overlayState = Overlay.of(context);

      overlayEntry = OverlayEntry(
        builder: (context) {
          return Positioned(
            bottom: MediaQuery.of(context).viewInsets.bottom,
            right: 0.0,
            left: 0.0,
            child: CloseKeyboardButton(
              closeButtonLabel: closeButtonLabel,
              closeButtonLabelStyle: closeButtonLabelStyle,
            ),
          );
        },
      );

      overlayState.insert(overlayEntry);
    }
  }

  void removeOverlay() {
    if (overlayEntry != null) {
      overlayEntry.remove();
      overlayEntry = null;
    }
  }
}
